<?php

namespace Drupal\content_model_documentation\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Content Model Document entities.
 *
 * @ingroup cm_document
 */
interface CMDocumentInterface extends ContentEntityInterface, RevisionLogInterface, EntityChangedInterface, EntityPublishedInterface, EntityOwnerInterface {

  /**
   * Gets the CMDocument name.
   *
   * @return string
   *   Name of the CMDocument.
   */
  public function getName(): string;

  /**
   * Sets the CMDocument name.
   *
   * @param string $name
   *   The CMDocument name.
   *
   * @return \Drupal\content_model_documentation\Entity\CMDocumentInterface
   *   The called CMDocument entity.
   */
  public function setName(string $name): CMDocumentInterface;

  /**
   * Gets the CMDocument creation timestamp.
   *
   * @return int
   *   Creation timestamp of the CMDocument.
   */
  public function getCreatedTime();

  /**
   * Sets the CMDocument creation timestamp.
   *
   * @param int $timestamp
   *   The CMDocument creation timestamp.
   *
   * @return \Drupal\content_model_documentation\Entity\CMDocumentInterface
   *   The called CMDocument entity.
   */
  public function setCreatedTime(int $timestamp): CMDocumentInterface;

}
